@@ -7,9 +7,9 @@ RDF::RDFa::Generator - generate some data in RDFa
 package RDF::RDFa::Generator;
 
 use 5.008;
-use common::sense;
+use strict;
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 use RDF::RDFa::Generator::HTML::Head;
 use RDF::RDFa::Generator::HTML::Hidden;
