@@ -7,11 +7,11 @@ RDF::RDFa::Generator::HTML::Pretty::Note - a note about something
 package RDF::RDFa::Generator::HTML::Pretty::Note;
 
 use 5.008;
-use common::sense;
+use strict;
 use constant XHTML_NS => 'http://www.w3.org/1999/xhtml';
 use XML::LibXML qw':all';
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 =head1 DESCRIPTION
 
